==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'អាសយដ្ឋានវ៉ែបសៃថ៍ របស់​អ្នក', # MODIF
	'form_pet_aucune_signature' => 'គ្មាន​ហត្ថលេខា​ ត្រូវ​នឹងអក្សរ​កូដ​នេះ​...', # MODIF
	'form_pet_confirmation' => 'សូម​បញ្ជាក់​ទទួលស្គាល់ ​ហត្ថលេខា​ របស់​អ្នក៖',
	'form_pet_deja_signe' => 'អ្នក​ធ្លាប់បាន ​ចុះហត្ថលេខា អត្ថបទ​នេះ។',
	'form_pet_envoi_mail_confirmation' => 'មួយអ៊ីមែវល៍បញ្ជាក់​ទទួលស្គាល់ ​ទើបត្រូវបានផ្ញើ​ទៅ​ @email@។ អ្នកត្រូវតែចូល​មើល អាសយដ្ឋានវ៉ែប បានប្រាប់ ក្នុងអ៊ីមែវល៍នេះ​ ដើម្បីធ្វើសុពលភាពហត្ថលេខា ​របស់​អ្នក។', # MODIF
	'form_pet_mail_confirmation' => 'សួស្ដី, 
 
អ្នកបានសួររក ចុះហត្ថលេខា បណ្តឹងជំទាស់៖ 
  @titre@.
 អ្នក​បាន​ផ្ដល់ ​ពត៌មាន ខាងក្រោម៖
 ឈ្មោះ ៖ @nom_email@
 វ៉ែបសៃថ៍ ៖ @nom_site@ - @url_site@
@message@
 
 សំខាន់​...
 ​ដើម្បី​សុពលភាព​ហត្ថលេខា ​របស់​អ្នក, អ្នកចាំបាច់ត្រូវ​ភ្ជាប់​ទៅ​ អាសយដ្ឋាន​ខាងក្រោម (បើមិនដូច្នោះ, សំណើ ​របស់​អ្នក ​នឹង​ត្រូវ​បដិសេធ​)៖

     @url@


​អរគុណ ចំពោះការ​ចូលរួម របស់អ្នក
',
	'form_pet_message_commentaire' => 'មួយសារ មួយវិចារ ឬ  ?', # MODIF
	'form_pet_nom_site2' => 'ឈ្មោះ​វ៉ែបសៃថ៍ របស់​អ្នក', # MODIF
	'form_pet_probleme_liens' => 'សូមកែប្រែ សាររបស់អ្នក, យកចេញ គ្រប់តំណភ្ជាប់។',
	'form_pet_probleme_technique' => 'បញ្ហា​បច្ចេកទេស, ហត្ថលេខាតាំងអស់ ​ត្រូវ​បាន​ពន្យួរ បណ្តោះអាសន្ន។',
	'form_pet_signature_validee' => 'ហត្ថលេខា ​របស់​អ្នក មាន​សុពលភាព ។ អរគុណ !',
	'form_pet_site_deja_enregistre' => 'បានចុះបញ្ជីហើយ វ៉ែបសៃថ៍នេះ។',
	'form_pet_url_invalide' => 'អាសយដ្ឋាន URL ដែល​អ្នក​បានបង្ហាញ គ្មានសុពលភាព។',
	'form_pet_votre_email' => 'អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក',
	'form_pet_votre_nom' => 'ឈ្មោះ ឬ ​ឈ្មោះ​ហៅ​ក្រៅ​ របស់​អ្នក', # MODIF
	'form_pet_votre_site' => 'បើ​អ្នកមាន មួយវ៉ែបសៃថ៍, អ្នក​អាច​បង្ហាញវា ​ខាងក្រោម',

	// I
	'info_adresse_email' => 'អាសយដ្ឋាន អ៊ីមែវល៍៖',
	'info_signature_supprimee' => 'បានលុបចេញ ហត្ថលេខា',
	'info_signature_supprimee_erreur' => 'កំហុស ៖ អក្សរកូដ លុបចេញនេះ គ្មានត្រូវតាម ហត្ថលេខាណាមួយ', # MODIF
	'info_site_web' => 'វ៉ែប​​សៃថ៍ ៖',

	// L
	'lien_reponse_article' => 'ចំលើយ ទៅ​អត្ថបទ'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'សកម្ម បណ្តឹងជំទាស់',
	'bouton_radio_pas_petition' => 'គ្មាន បណ្តឹងជំទាស់',
	'bouton_radio_petition_activee' => 'បានសកម្ម បណ្តឹងជំទាស់',
	'bouton_radio_supprimer_petition' => 'លុបចេញ បណ្តឹងជំទាស់',

	// F
	'form_pet_adresse_site' => 'អាសយដ្ឋានវ៉ែបសៃថ៍ របស់​អ្នក', # MODIF
	'form_pet_aucune_signature' => 'គ្មាន​ហត្ថលេខា​ ត្រូវ​នឹងអក្សរ​កូដ​នេះ​...', # MODIF
	'form_pet_confirmation' => 'សូម​បញ្ជាក់​ទទួលស្គាល់ ​ហត្ថលេខា​ របស់​អ្នក៖',
	'form_pet_deja_signe' => 'អ្នក​ធ្លាប់បាន ​ចុះហត្ថលេខា អត្ថបទ​នេះ។',
	'form_pet_envoi_mail_confirmation' => 'មួយអ៊ីមែវល៍បញ្ជាក់​ទទួលស្គាល់ ​ទើបត្រូវបានផ្ញើ​ទៅ​ @email@។ អ្នកត្រូវតែចូល​មើល អាសយដ្ឋានវ៉ែប បានប្រាប់ ក្នុងអ៊ីមែវល៍នេះ​ ដើម្បីធ្វើសុពលភាពហត្ថលេខា ​របស់​អ្នក។', # MODIF
	'form_pet_mail_confirmation' => 'សួស្ដី, 
 
អ្នកបានសួររក ចុះហត្ថលេខា បណ្តឹងជំទាស់៖ 
  @titre@.
 អ្នក​បាន​ផ្ដល់ ​ពត៌មាន ខាងក្រោម៖
 ឈ្មោះ ៖ @nom_email@
 វ៉ែបសៃថ៍ ៖ @nom_site@ - @url_site@
@message@
 
 សំខាន់​...
 ​ដើម្បី​សុពលភាព​ហត្ថលេខា ​របស់​អ្នក, អ្នកចាំបាច់ត្រូវ​ភ្ជាប់​ទៅ​ អាសយដ្ឋាន​ខាងក្រោម (បើមិនដូច្នោះ, សំណើ ​របស់​អ្នក ​នឹង​ត្រូវ​បដិសេធ​)៖

     @url@


​អរគុណ ចំពោះការ​ចូលរួម របស់អ្នក
',
	'form_pet_message_commentaire' => 'មួយសារ មួយវិចារ ឬ  ?', # MODIF
	'form_pet_nom_site2' => 'ឈ្មោះ​វ៉ែបសៃថ៍ របស់​អ្នក', # MODIF
	'form_pet_probleme_liens' => 'សូមកែប្រែ សាររបស់អ្នក, យកចេញ គ្រប់តំណភ្ជាប់។',
	'form_pet_probleme_technique' => 'បញ្ហា​បច្ចេកទេស, ហត្ថលេខាតាំងអស់ ​ត្រូវ​បាន​ពន្យួរ បណ្តោះអាសន្ន។',
	'form_pet_signature_validee' => 'ហត្ថលេខា ​របស់​អ្នក មាន​សុពលភាព ។ អរគុណ !',
	'form_pet_site_deja_enregistre' => 'បានចុះបញ្ជីហើយ វ៉ែបសៃថ៍នេះ។',
	'form_pet_url_invalide' => 'អាសយដ្ឋាន URL ដែល​អ្នក​បានបង្ហាញ គ្មានសុពលភាព។',
	'form_pet_votre_email' => 'អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក',
	'form_pet_votre_nom' => 'ឈ្មោះ ឬ ​ឈ្មោះ​ហៅ​ក្រៅ​ របស់​អ្នក', # MODIF
	'form_pet_votre_site' => 'បើ​អ្នកមាន មួយវ៉ែបសៃថ៍, អ្នក​អាច​បង្ហាញវា ​ខាងក្រោម',

	// I
	'info_adresse_email' => 'អាសយដ្ឋាន អ៊ីមែវល៍៖',
	'info_signature_supprimee' => 'បានលុបចេញ ហត្ថលេខា',
	'info_signature_supprimee_erreur' => 'កំហុស ៖ អក្សរកូដ លុបចេញនេះ គ្មានត្រូវតាម ហត្ថលេខាណាមួយ', # MODIF
	'info_site_web' => 'វ៉ែប​​សៃថ៍ ៖',

	// L
	'lien_reponse_article' => 'ចំលើយ ទៅ​អត្ថបទ'
);

?>
